@@ -26,7 +26,7 @@ require 5.004;
 use strict;
 
 use RPC::PlServer 0.2001;
-# require DBI; # deferred till AcceptVersion() to aid threading
+require DBI;
 require Config;
 
 
@@ -215,7 +215,7 @@ sub CallMethod {
     # $dbh. However, we'd have a reference loop in that case and
     # I would be concerned about garbage collection. :-(
     $dbh->{'private_server'} = $server;
-    $server->Debug("CallMethod: => " . join(",", @_));
+    $server->Debug("CallMethod: => " . do { local $^W; join(",", @_)});
     my @result = eval { $server->SUPER::CallMethod(@_) };
     my $msg = $@;
     undef $dbh->{'private_server'};
@@ -223,7 +223,7 @@ sub CallMethod {
 	$server->Debug("CallMethod died with: $@");
 	die $msg;
     } else {
-	$server->Debug("CallMethod: <= " . join(",", @result));
+	$server->Debug("CallMethod: <= " . do { local $^W; join(",", @result) });
     }
     @result;
 }
@@ -382,7 +382,7 @@ DBI::ProxyServer - a server for the DBD::Proxy driver
 DBI::Proxy Server is a module for implementing a proxy for the DBI proxy
 driver, DBD::Proxy. It allows access to databases over the network if the
 DBMS does not offer networked operations. But the proxy server might be
-usefull for you, even if you have a DBMS with integrated network
+useful for you, even if you have a DBMS with integrated network
 functionality: It can be used as a DBI proxy in a firewalled environment.
 
 DBI::ProxyServer runs as a daemon on the machine with the DBMS or on the
@@ -414,7 +414,7 @@ L<RPC::PlServer>. See L<Net::Daemon>. Available options include
 =item I<chroot> (B<--chroot=dir>)
 
 (UNIX only)  After doing a bind(), change root directory to the given
-directory by doing a chroot(). This is usefull for security, but it
+directory by doing a chroot(). This is useful for security, but it
 restricts the environment a lot. For example, you need to load DBI
 drivers in the config file or you have to create hard links to Unix
 sockets, if your drivers are using them. For example, with MySQL, a
@@ -465,7 +465,7 @@ B<daemon>.
 =item I<group> (B<--group=gid>)
 
 After doing a bind(), change the real and effective GID to the given.
-This is usefull, if you want your server to bind to a privileged port
+This is useful, if you want your server to bind to a privileged port
 (<1024), but don't want the server to execute as root. See also
 the --user option.
 
@@ -506,7 +506,7 @@ you use the "--mode=fork" option.
 Finally there's a single-connection mode: If the server has accepted a
 connection, he will enter the Run() method. No other connections are
 accepted until the Run() method returns (if the client disconnects).
-This operation mode is usefull if you have neither threads nor fork(),
+This operation mode is useful if you have neither threads nor fork(),
 for example on the Macintosh. For debugging purposes you can force this
 mode with "--mode=single".
 
@@ -518,7 +518,7 @@ given location. Default is to not create a pidfile.
 =item I<user> (B<--user=uid>)
 
 After doing a bind(), change the real and effective UID to the given.
-This is usefull, if you want your server to bind to a privileged port
+This is useful, if you want your server to bind to a privileged port
 (<1024), but don't want the server to execute as root. See also
 the --group and the --chroot options.
 
@@ -526,11 +526,18 @@ UID's can be passed as group names or numeric values.
 
 =item I<version> (B<--version>)
 
-Supresses startup of the server; instead the version string will
+Suppresses startup of the server; instead the version string will
 be printed and the program exits immediately.
 
 =back
 
+=head1 SHUTDOWN
+
+DBI::ProxyServer is built on L<RPC::PlServer> which is, in turn, built on L<Net::Daemon>.
+
+You should refer to L<Net::Daemon> for how to shutdown the server, except that
+you can't because it's not currently documented there (as of v0.43).
+The bottom-line is that it seems that there's no support for graceful shutdown.
 
 =head1 CONFIGURATION FILE
 
@@ -538,7 +545,7 @@ The configuration file is just that of I<RPC::PlServer> or I<Net::Daemon>
 with some additional attributes in the client list.
 
 The config file is a Perl script. At the top of the file you may include
-arbitraty Perl source, for example load drivers at the start (usefull
+arbitrary Perl source, for example load drivers at the start (useful
 to enhance performance), prepare a chroot environment and so on.
 
 The important thing is that you finally return a hash ref of option
@@ -597,7 +604,7 @@ every workstation shall be able to execute every query.
 There is a perl program "dbiproxy" which runs on a machine which is able
 to connect to all the databases we wish to reach. All Perl-DBD-drivers must
 be installed on this machine. You can also reach databases for which drivers 
-are not available on the machine where you run the programm querying the 
+are not available on the machine where you run the program querying the 
 database, e.g. ask MS-Access-database from Linux.
 
 Create a configuration file "proxy_oracle.cfg" at the dbproxy-server:
@@ -617,7 +624,7 @@ Create a configuration file "proxy_oracle.cfg" at the dbproxy-server:
 		# hint to organize:
 		# the most specialized rules for single machines/users are 1st
 		# then the denying rules
-		# the the rules about whole networks
+		# then the rules about whole networks
 
 		# rule: internal_webserver
 		# desc: to get statistical information
@@ -644,7 +651,7 @@ Create a configuration file "proxy_oracle.cfg" at the dbproxy-server:
 		},
 
 		# rule: employee_workplace
-		# desc: get detailled informations
+		# desc: get detailed information
 		{
 			# any IP-address is meant here
 			mask => '^10\.95\.81\.(\d+)$',
@@ -680,7 +687,7 @@ Start the proxyserver like this:
 
 =head2 Testing the connection from a remote machine
 
-Call a programm "dbish" from your commandline. I take the machine from rule "internal_webserver"
+Call a program "dbish" from your commandline. I take the machine from rule "internal_webserver"
 
 	dbish "dbi:Proxy:hostname=oracle.zdf;port=12400;dsn=dbi:Oracle:e01" informationdesk xxx
 
@@ -802,7 +809,7 @@ Controlling which person at which machine is allowed to access
 
 =item * "mask" is a perl regular expression against the plain ip-address of the machine which wishes to connect _or_ the reverse-lookup from a nameserver.
 
-=item * "accept" tells the dbiproxy-server wether ip-adresse like in "mask" are allowed to connect or not (0/1)
+=item * "accept" tells the dbiproxy-server whether ip-adresse like in "mask" are allowed to connect or not (0/1)
 
 =item * "users" is a reference to a list of usernames which must be matched, this is NOT a regular expression.
 
@@ -810,7 +817,7 @@ Controlling which person at which machine is allowed to access
 
 Controlling which SQL-statements are allowed
 
-You can put every SQL-statement you like in simply ommiting "sql => ...", but the more important thing is to restrict the connection so that only allowed queries are possible.
+You can put every SQL-statement you like in simply omitting "sql => ...", but the more important thing is to restrict the connection so that only allowed queries are possible.
 
 If you include an sql-section in your config-file like this:
 
